.. _index:

Security
========

Security extension provides interface to security testing tools.

Following tools are supported:

* MSF: MetaSploit Framework
* ZAP: Zed Attack Proxy

.. toctree::
   :hidden:
   
   rst/install
   rst/tutor
   rst/module
   rst/refman